"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.commitTypes = {
    feat: 'Features',
    fix: 'Bug Fixes',
    style: 'Styles',
    perf: 'Performance Improvements',
    docs: 'Documentation',
    refactor: 'Refactoring',
    test: 'Tests',
    revert: 'Reverts'
};
exports.commitTypesOrder = Object.values(exports.commitTypes);
function changelogTransformer(repositoryUrl) {
    return (commit) => {
        commit.type = exports.commitTypes[commit.type];
        if (!commit.type) {
            return;
        }
        if (commit.scope === '*') {
            commit.scope = '';
        }
        if (typeof commit.hash === 'string') {
            commit.hash = commit.hash.substring(0, 7);
        }
        const issues = [];
        if (typeof commit.subject === 'string') {
            commit.subject = commit.subject
                .replace(/#([0-9]+)/g, function (match, issue) {
                issues.push(issue);
                return `[#${issue}](${repositoryUrl}/issues/${issue})`;
            })
                .replace(/@([a-zA-Z0-9_]+)/g, '[@$1](https://github.com/$1)');
        }
        commit.references = commit.references.filter((reference) => {
            return issues.indexOf(reference.issue) === -1;
        });
        commit.notes.forEach((note) => {
            note.title = 'BREAKING CHANGES';
        });
        return commit;
    };
}
exports.changelogTransformer = changelogTransformer;
;
function changelogCommitGroupsSort(a, b) {
    return exports.commitTypesOrder.indexOf(a.title) > exports.commitTypesOrder.indexOf(b.title);
}
exports.changelogCommitGroupsSort = changelogCommitGroupsSort;
;
//# sourceMappingURL=changelog-transform.js.map